@@ -1,21 +1,8 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function
 
-del absolute_import, division, print_function
-
-__all__ = (
-    "options",
-    "regular",
-    "variable",
-    "integer",
-    "str_category",
-    "int_category",
-    "transform",
-)
-
-from ... import axis as _axis
-
+from ..._core.axis import options
 from ..._internal.axis import (
-    options,
     Axis,
     regular,
     variable,
@@ -24,3 +11,16 @@ from ..._internal.axis import (
     int_category,
 )
 from . import transform
+
+del absolute_import, division, print_function
+
+__all__ = (
+    "options",
+    "Axis",
+    "regular",
+    "variable",
+    "integer",
+    "str_category",
+    "int_category",
+    "transform",
+)
